@@ -1,4 +1,3 @@
-
 #' Explain how a package depends on other packages
 #'
 #' Extract dependency chains from `pkg` to `deps`.
@@ -33,8 +32,7 @@ pkg_deps_explain <- function(pkg, deps, upgrade = TRUE, dependencies = NA) {
     function(...) {
       get("pkg_deps_explain_internal", asNamespace("pak"))(...)
     },
-    list(pkg = pkg, deps = deps, upgrade = upgrade,
-         dependencies = dependencies)
+    list(pkg = pkg, deps = deps, upgrade = upgrade, dependencies = dependencies)
   )
 }
 
@@ -47,11 +45,11 @@ pkg_deps_explain_internal <- function(pkg, deps, upgrade, dependencies = NA) {
   types <- pkgdepends::as_pkg_dependencies(dependencies)
   deps1 <- local({
     d1 <- data$deps[[wpkg]]
-    pk <- d1$package[ tolower(d1$type) %in% tolower(types[[1]]) ]
+    pk <- d1$package[tolower(d1$type) %in% tolower(types[[1]])]
     na_omit(match(pk, data$package))
   })
   adjlist <- lapply(data$deps, function(di) {
-    p <- di$package[ tolower(di$type) %in% tolower(types[[2]]) ]
+    p <- di$package[tolower(di$type) %in% tolower(types[[2]])]
     p <- setdiff(p, "R")
     na_omit(match(p, data$package))
   })
@@ -81,7 +79,6 @@ pkg_deps_explain_internal <- function(pkg, deps, upgrade, dependencies = NA) {
       if (dpkg %in% deps) {
         paths[[dpkg]] <- c(paths[[dpkg]], list(data$package[stack[1:ssize]]))
       }
-
     } else {
       ssize <- ssize - 1L
       nptr[act] <- 1L
@@ -90,7 +87,10 @@ pkg_deps_explain_internal <- function(pkg, deps, upgrade, dependencies = NA) {
   }
 
   ret <- list(
-    pkg = pkg, deps = deps, dependencies = dependencies, paths = paths
+    pkg = pkg,
+    deps = deps,
+    dependencies = dependencies,
+    paths = paths
   )
   class(ret) <- "pak_deps_explain"
 
@@ -100,7 +100,6 @@ pkg_deps_explain_internal <- function(pkg, deps, upgrade, dependencies = NA) {
 #' @export
 
 format.pak_deps_explain <- function(x, ...) {
-
   format_path1 <- function(p1) {
     strwrap(paste0(p1, collapse = " -> "), exdent = 2L)
   }
