@@ -88,9 +88,13 @@ install_order <- function() {
     "pkgcache",
     # curl, jsonlite
     "pkgsearch",
+    "yaml",
     # callr, cli, curl, desc, filelock, jsonlite, lpSolve, pkgbuild,
     # pkgcache, processx, ps, R6, zip
-    "pkgdepends"
+    "pkgdepends",
+    # filelock, R6, yaml
+    "keyring",
+    NULL
   )
 
   pkgs
