@@ -11,14 +11,20 @@ test_that("output is printed on failure", {
   on.exit(unlink(tmp), add = TRUE)
 
   expect_error(
-    callr::r(stdout = tmp, stderr = tmp, function(pkg) {
-      # if this is not R CMD check, use `load_all()``
-      # otherwise `load_all()` does not work, because we are not in the
-      # package tree in `R CMD check`.
-      if (Sys.getenv("_R_CHECK_PACKAGE_NAME_") == "") pkgload::load_all()
-      options(rlib_interactive = TRUE)
-      pak::pkg_install(pkg)
-    }, list(pkg = badcompile))
+    callr::r(
+      stdout = tmp,
+      stderr = tmp,
+      function(pkg) {
+        # if this is not R CMD check, use `load_all()``
+        # otherwise `load_all()` does not work, because we are not in the
+        # package tree in `R CMD check`.
+        if (Sys.getenv("_R_CHECK_PACKAGE_NAME_") == "") pkgload::load_all()
+        options(rlib_interactive = TRUE)
+        pak::pkg_install(pkg)
+      },
+      list(pkg = badcompile)
+    ),
+    class = "callr_error"
   )
 
   lines <- readLines(tmp)
@@ -30,12 +36,18 @@ test_that("output is printed on failure", {
   )))
 
   expect_error(
-    callr::r(stdout = tmp, stderr = tmp, function(pkg) {
-      # see above
-      if (Sys.getenv("_R_CHECK_PACKAGE_NAME_") == "") pkgload::load_all()
-      options(rlib_interactive = FALSE)
-      pak::pkg_install(pkg)
-    }, list(pkg = badcompile))
+    callr::r(
+      stdout = tmp,
+      stderr = tmp,
+      function(pkg) {
+        # see above
+        if (Sys.getenv("_R_CHECK_PACKAGE_NAME_") == "") pkgload::load_all()
+        options(rlib_interactive = FALSE)
+        pak::pkg_install(pkg)
+      },
+      list(pkg = badcompile)
+    ),
+    class = "callr_error"
   )
 
   lines <- readLines(tmp)
